@@ -15,7 +15,7 @@ from marshmallow import Schema, ValidationError, fields, validate, post_load
 from sqlalchemy.sql.schema import Sequence
 
 from . import exceptions as post_exceptions
-from .auth.perms import SessionContext
+from .auth.clauses import SessionContext
 from .fields import (
     Set, Relationship, AutoImpliedForeignResource,
     AutoSessionField, AutoSessionForeignResource,
@@ -777,7 +777,7 @@ class ViewsClassBase(web.View):
             # if PK isn't set to auto-increment, and it's of AutoSession type,
             # don't include it in a pre-rendered query
             if not is_autopk:
-                values.append(f'%({cls.pk_column_name})')
+                values.append(f'%({cls.pk_column_name})s')
             else:
                 cls.has_autopk = True
 
@@ -1023,8 +1023,11 @@ class ViewsBase(ViewsClassBase, CommonViewMixin):
             return query_maker(select_with, compile_selects=False, request_type=self.request_type)
 
     def _render_insert_query(self, payload, on_conflict=''):
-        vals = ','.join(f"%({colname})s" for colname in payload)
-        cols = ','.join(payload)
+        vals = ','.join(f"%({colname})s" for colname in payload
+                        if (colname != self.pk_column_name) or self.has_autopk)
+        cols = ','.join(colname for colname in payload
+                        if (colname != self.pk_column_name) or self.has_autopk)
+
         if vals and not self.has_autopk:
             vals = ',' + vals
             cols = ',' + cols
@@ -1043,9 +1046,10 @@ class ViewsBase(ViewsClassBase, CommonViewMixin):
         joins = []
         usings = []
         froms = []  # for updates only
-        wheres = deque()
         values = {}
 
+        wheres = deque()
+
         # inject authorization condition
         with suppress(KeyError, TypeError):
             wheres.append(self.request.auth_conditions['stmt'])
@@ -1061,7 +1065,7 @@ class ViewsBase(ViewsClassBase, CommonViewMixin):
             if relation_in_payload:
                 values.update({m2m_field: relation_in_payload})
                 wheres.append(m2m_field_translated)
-        
+
         for fk_field, join_obj in self.schema._join_to_schema_where_stmt.items():
             linked_schema = join_obj['linked_schema']
             if fk_field in self.tables_to_join:
@@ -1085,12 +1089,13 @@ class ViewsBase(ViewsClassBase, CommonViewMixin):
                     pk = linked_schema.pk_column_name
                     wheres.appendleft(f'"{linked_tb_name}".{pk}="{tablename}".{fk_field}')
 
-        for key in cleaned_payload.copy():
-            wheres.append(f'"{tablename}".{key}=%(w_{key})s')
+        if not self.request.auth_conditions.get('has_open_clauses', False):
+            for key in cleaned_payload.copy():
+                wheres.append(f'"{tablename}".{key}=%(w_{key})s')
+            values.update({f'w_{k}': v for k, v in cleaned_payload.items()})
+        else:
+            values = cleaned_payload
 
-        values.update({f'w_{k}': v for k, v in cleaned_payload.items()})
-
-        wheres_q = ' AND '.join(wheres) or ' 1=1 '
         joins = ' '.join(joins)
         using = ','.join(usings)
         froms = ','.join(froms)
@@ -1099,6 +1104,15 @@ class ViewsBase(ViewsClassBase, CommonViewMixin):
         if froms:
             froms = f'FROM "{froms}"'
 
+        # if not self.request.auth_conditions['has_open_clauses']:
+        #     joins, using, froms, values, wheres = self._whereize_generic_query(cleaned_payload, wheres, in_update, in_delete)
+        # else:
+        #     joins = using = froms = wheres = ""
+        #     values = cleaned_payload
+
+        wheres_q = ' AND '.join(wheres) or ' 1=1 '
+
+        # values.update(cleaned_payload.copy(])
         return query.format(where=wheres_q, joins=joins, using=using, froms=froms), values
 
 
